# This file has been generated


build_system = 'AppVeyor'
build_id = '32555898'
build_number = '657'
build_version = '1.0.657'
job_id = 'yv2aebaom0fsi2f4'
job_url = 'https://ci.appveyor.com/project/KyleAltendorf/pm/build/job/yv2aebaom0fsi2f4'



# This file was automatically generated by sub\epyqlib\epyqlib\cli\generateversion.py
__version_build_time__ = '2020-04-30T12:46:41.168533'

__version__ = '2020.4.10'
__sha__ = '89b7d1391665eb4a9b3fae4bc59013d297206944'
__revision__ = '89b7d1391665eb4a9b3fae4bc59013d297206944'
